#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from setuptools import find_packages
from setuptools import setup


here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.md')) as f:
    README = f.read()

setup(
    name="mylib",
    version='0.0',
    long_description=README,
    classifiers=[
            'Programming Language :: Python',
    ],
    install_requires=[
        'progressbar',
    ],
    extras_require={
        'dev': [
            'pytest',
            'mocker',
            'pytest-mock',
            'pylint',
        ],
        'config': [
            'configparser',
            'argcomplete',
            'keyring',
            'systemd-python',
        ],
        'ldap': [
            'python-ldap',
            'python-dateutil',
            'pytz',
        ],
        'email': [
            'email3',
            'mako',
        ],
        'pgsql': [
            'psycopg2',
        ],
        'oracle': [
            'cx_Oracle',
        ],
        'mysql': [
            'mysqlclient',
        ],
    },
    author='Benjamin Renard',
    author_email='brenard@zionetrix.net',
    url='https://gogs.zionetrix.net/bn8/python-mylib',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'mylib-test-email = mylib.scripts.email_test:main',
            'mylib-test-pbar = mylib.scripts.pbar_test:main',
            'mylib-test-report = mylib.scripts.report_test:main',
            'mylib-test-ldap = mylib.scripts.ldap_test:main',
        ],
    },
)
